changeset 16021:5b9a35f9b2e4

Fix some overzealous s/gaim/purple/ stuff.
author Daniel Atallah <daniel.atallah@gmail.com>
date Mon, 09 Apr 2007 02:04:03 +0000
parents 5e5b7f9fcda8
children ec049b8a8619
files pidgin/win32/winpidgin.c
diffstat 1 files changed, 14 insertions(+), 14 deletions(-) [+]
line wrap: on
line diff
--- a/pidgin/win32/winpidgin.c	Mon Apr 09 00:55:25 2007 +0000
+++ b/pidgin/win32/winpidgin.c	Mon Apr 09 02:04:03 2007 +0000
@@ -111,7 +111,7 @@
 	HMODULE hmod;
 	HKEY hkey;
 #ifdef PORTABLE
 	/* We assume that GTK+ is installed under \\path\to\Purple\..\GTK
 	 * First we find \\path\to
 	 */
 	if (GetModuleFileName(NULL, path, MAX_PATH) != 0) {
@@ -136,15 +136,15 @@
 
 	if (path) {
 		/* Set up the settings dir base to be \\path\to
-		 * The actual settings dir will be \\path\to\.purple */
-		char settingsdir[strlen(path) + strlen("PURPLEHOME=") + 1];
-		char aspelldir[strlen(path) + strlen("PURPLE_ASPELL_DIR=\\Aspell\\bin") + 1];
+		 * The actual settings dir will be \\path\to\.pidgin */
+		char settingsdir[strlen(path) + strlen("PIDGINHOME=") + 1];
+		char aspelldir[strlen(path) + strlen("PIDGIN_ASPELL_DIR=\\Aspell\\bin") + 1];
 
-		snprintf(settingsdir, sizeof(settingsdir), "PURPLEHOME=%s", path);
+		snprintf(settingsdir, sizeof(settingsdir), "PIDGINHOME=%s", path);
 		printf("Setting settings dir: %s\n", settingsdir);
 		putenv(settingsdir);
 
-		snprintf(aspelldir, sizeof(aspelldir), "PURPLE_ASPELL_DIR=%s\\Aspell\\bin", path);
+		snprintf(aspelldir, sizeof(aspelldir), "PIDGIN_ASPELL_DIR=%s\\Aspell\\bin", path);
 		printf("%s", aspelldir);
 		putenv(aspelldir);
 
@@ -390,8 +390,8 @@
 	return posix;
 }
 
-/* Determine and set Purple locale as follows (in order of priority):
-   - Check PURPLELANG env var
+/* Determine and set Pidgin locale as follows (in order of priority):
+   - Check PIDGINLANG env var
    - Check NSIS Installer Language reg value
    - Use default user locale
 */
@@ -403,12 +403,12 @@
 	DWORD datalen = 10;
 #endif
 
-	/* Check if user set PURPLELANG env var */
-	if ((locale = getenv("PURPLELANG")))
+	/* Check if user set PIDGINLANG env var */
+	if ((locale = getenv("PIDGINLANG")))
 		return locale;
 
 #ifndef PORTABLE
-	if (read_reg_string(HKEY_CURRENT_USER, "SOFTWARE\\purple",
+	if (read_reg_string(HKEY_CURRENT_USER, "SOFTWARE\\pidgin",
 			"Installer Language", (LPBYTE) &data, &datalen)) {
 		if ((locale = winpidgin_lcid_to_posix(atoi(data))))
 			return locale;
@@ -581,17 +581,17 @@
 	}
 
 #ifndef PORTABLE
-	if (!getenv("PURPLE_NO_DLL_CHECK"))
+	if (!getenv("PIDGIN_NO_DLL_CHECK"))
 #endif
 		dll_prep();
 
 	winpidgin_set_locale();
 	/* If help or version flag used, do not check Mutex */
 	if (!strstr(lpszCmdLine, "-h") && !strstr(lpszCmdLine, "-v"))
-		if (!getenv("PURPLE_MULTI_INST") && !winpidgin_set_running())
+		if (!getenv("PIDGIN_MULTI_INST") && !winpidgin_set_running())
 			return 0;
 
 	/* Now we are ready for Purple .. */
 	if ((hmod = LoadLibrary("pidgin.dll"))) {
 		pidgin_main = (LPFNPIDGINMAIN) GetProcAddress(hmod, "pidgin_main");
 	}
@@ -111,7 +111,7 @@
 	HKEY hkey;
 #ifdef PORTABLE
-	/* We assume that GTK+ is installed under \\path\to\Purple\..\GTK
+	/* We assume that GTK+ is installed under \\path\to\Pidgin\..\GTK
 	 * First we find \\path\to
 	 */
@@ -581,17 +581,17 @@
 			return 0;
 
-	/* Now we are ready for Purple .. */
+	/* Now we are ready for Pidgin .. */
 	if ((hmod = LoadLibrary("pidgin.dll"))) {
 		pidgin_main = (LPFNPIDGINMAIN) GetProcAddress(hmod, "pidgin_main");